@@ -4,7 +4,6 @@
 
 import click
 
-from ._common import PathType
 from ._filename import sanitize_filename, validate_filename
 from ._filepath import sanitize_filepath, validate_filepath
 from .error import ValidationError
@@ -34,41 +33,15 @@ def validate_filepath_arg(ctx, param, value) -> str:
     return value
 
 
-def sanitize_filename_arg(ctx, param, value) -> PathType:
+def sanitize_filename_arg(ctx, param, value: str) -> str:
     if not value:
         return ""
 
     return sanitize_filename(value)
 
 
-def sanitize_filepath_arg(ctx, param, value) -> PathType:
+def sanitize_filepath_arg(ctx, param, value: str) -> str:
     if not value:
         return ""
 
     return sanitize_filepath(value)
-
-
-def filename(ctx, param, value):  # pragma: no cover
-    # Deprecated
-    if not value:
-        return None
-
-    try:
-        validate_filename(value)
-    except ValidationError as e:
-        raise click.BadParameter(str(e))
-
-    return sanitize_filename(value)
-
-
-def filepath(ctx, param, value):  # pragma: no cover
-    # Deprecated
-    if not value:
-        return None
-
-    try:
-        validate_filepath(value)
-    except ValidationError as e:
-        raise click.BadParameter(str(e))
-
-    return sanitize_filepath(value)
