@@ -20,7 +20,7 @@ from pathvalidate import (
     sanitize_filepath,
     validate_filepath,
 )
-from pathvalidate._common import is_pathlike_obj, unprintable_ascii_chars
+from pathvalidate._common import unprintable_ascii_chars
 from pathvalidate._filepath import FilePathSanitizer, FilePathValidator
 from pathvalidate.handler import raise_error, return_null_string, return_timestamp
 
@@ -44,7 +44,11 @@ random.seed(0)
 class Test_FileSanitizer:
     @pytest.mark.parametrize(
         ["test_platform", "expected"],
-        [["windows", Platform.WINDOWS], ["linux", Platform.LINUX], ["macos", Platform.MACOS]],
+        [
+            ["windows", Platform.WINDOWS],
+            ["linux", Platform.LINUX],
+            ["macos", Platform.MACOS],
+        ],
     )
     def test_normal_platform_auto(self, monkeypatch, test_platform, expected):
         if test_platform == "windows":
@@ -111,7 +115,11 @@ class Test_validate_filepath:
 
     @pytest.mark.parametrize(
         ["platform"],
-        [["linux"], ["macos"], ["posix"]],
+        [
+            ["linux"],
+            ["macos"],
+            ["posix"],
+        ],
     )
     def test_normal_only_whitespaces(self, platform):
         value = "  "
@@ -120,7 +128,10 @@ class Test_validate_filepath:
 
     @pytest.mark.parametrize(
         ["platform"],
-        [["windows"], ["universal"]],
+        [
+            ["windows"],
+            ["universal"],
+        ],
     )
     def test_abnormal_only_whitespaces(self, platform):
         value = "  "
@@ -187,15 +198,45 @@ class Test_validate_filepath:
         ],
     )
     def test_normal_max_len(self, value, platform, max_len, expected):
+        kwargs = {
+            "platform": platform,
+            "max_len": max_len,
+        }
+
         if expected is None:
-            validate_filepath(value, platform=platform, max_len=max_len)
-            assert is_valid_filepath(value, platform=platform, max_len=max_len)
+            validate_filepath(value, **kwargs)
+            assert is_valid_filepath(value, **kwargs)
             return
 
         with pytest.raises(ValidationError) as e:
-            validate_filepath(value, platform=platform, max_len=max_len)
+            validate_filepath(value, **kwargs)
         assert e.value.reason == ErrorReason.INVALID_LENGTH
 
+    @pytest.mark.parametrize(
+        ["value", "platform", "fs_encoding", "max_len", "expected"],
+        [
+            ["/tmp/" + "あ" * 83, "linux", "utf-8", 255, None],
+            ["/tmp/" + "あ" * 84, "linux", "utf-8", 255, ErrorReason.INVALID_LENGTH],
+            ["/tmp/" + "あ" * 121, "linux", "utf-16", 255, None],
+            ["/tmp/" + "あ" * 122, "linux", "utf-16", 255, ErrorReason.INVALID_LENGTH],
+        ],
+    )
+    def test_max_len_fs_encoding(self, value, platform, fs_encoding, max_len, expected):
+        kwargs = {
+            "platform": platform,
+            "max_len": max_len,
+            "fs_encoding": fs_encoding,
+        }
+
+        if expected is None:
+            validate_filepath(value, **kwargs)
+            assert is_valid_filepath(value, **kwargs)
+            return
+
+        with pytest.raises(ValidationError) as e:
+            validate_filepath(value, **kwargs)
+        assert e.value.reason == expected
+
     @pytest.mark.parametrize(
         ["value", "min_len", "max_len", "expected"],
         [
@@ -208,13 +249,18 @@ class Test_validate_filepath:
         ],
     )
     def test_minmax_len(self, value, min_len, max_len, expected):
+        kwargs = {
+            "min_len": min_len,
+            "max_len": max_len,
+        }
+
         if expected is None:
-            validate_filepath(value, min_len=min_len, max_len=max_len)
-            assert is_valid_filepath(value, min_len=min_len, max_len=max_len)
+            validate_filepath(value, **kwargs)
+            assert is_valid_filepath(value, **kwargs)
             return
 
         with pytest.raises(expected):
-            validate_filepath(value, min_len=min_len, max_len=max_len)
+            validate_filepath(value, **kwargs)
 
     @pytest.mark.parametrize(
         ["test_platform", "value", "expected"],
@@ -427,8 +473,8 @@ class Test_validate_filepath:
 
         assert e.value.reason == expected
         assert str(e.value) == (
-            r"invalid char found: invalids=('\r'), value='asdf\rsdf', "
-            "reason=INVALID_CHARACTER, target-platform=Windows"
+            r"[PV1100] invalid characters found: invalids=('\r'), value='asdf\rsdf', "
+            "target-platform=Windows"
         )  # noqa
 
     @pytest.mark.parametrize(
@@ -507,7 +553,14 @@ class Test_sanitize_filepath:
             for pair in AllPairs(
                 OrderedDict(
                     {
-                        "platform": ["posix", "linux", "macos"],
+                        "platform": [
+                            "posix",
+                            "linux",
+                            "macos",
+                            Platform.POSIX,
+                            Platform.LINUX,
+                            Platform.MACOS,
+                        ],
                         "c": INVALID_PATH_CHARS + unprintable_ascii_chars,
                         "repl": REPLACE_TEXTS,
                     }
@@ -519,7 +572,14 @@ class Test_sanitize_filepath:
             for pair in AllPairs(
                 OrderedDict(
                     {
-                        "platform": ["posix", "linux", "macos"],
+                        "platform": [
+                            "posix",
+                            "linux",
+                            "macos",
+                            Platform.POSIX,
+                            Platform.LINUX,
+                            Platform.MACOS,
+                        ],
                         "c": [":", "*", "?", '"', "<", ">", "|"],
                         "repl": REPLACE_TEXTS,
                     }
@@ -618,7 +678,7 @@ class Test_sanitize_filepath:
     def test_normal_pathlike(self, value, replace_text, expected):
         sanitized_name = sanitize_filepath(value, replace_text)
         assert sanitized_name == expected
-        assert is_pathlike_obj(sanitized_name)
+        assert isinstance(sanitized_name, Path)
 
         validate_filepath(sanitized_name)
         assert is_valid_filepath(sanitized_name)
@@ -734,17 +794,45 @@ class Test_sanitize_filepath:
         ],
     )
     def test_auto_platform_linux(self, value, expected):
+        kwargs = {
+            "platform": "auto",
+            "validate_after_sanitize": True,
+        }
+
         if isinstance(expected, str):
-            sanitized = sanitize_filepath(value, platform="auto")
+            sanitized = sanitize_filepath(value, **kwargs)
             assert is_valid_filepath(sanitized, platform="auto")
-        else:
-            with pytest.raises(expected):
-                sanitize_filepath(value, platform="auto")
+            return
+
+        with pytest.raises(expected) as e:
+            sanitize_filepath(value, **kwargs)
+        assert e.value.reason == ErrorReason.MALFORMED_ABS_PATH
+
+    @pytest.mark.parametrize(
+        ["platform", "value"],
+        [
+            ["windows", "CON \r"],
+        ],
+    )
+    def test_exception_invalid_after_sanitize(self, platform, value):
+        print(
+            "'{}'".format(
+                sanitize_filepath(value, platform=platform, validate_after_sanitize=False)
+            ),
+            file=sys.stderr,
+        )
+        with pytest.raises(ValidationError) as e:
+            sanitize_filepath(value, platform=platform, validate_after_sanitize=True)
+        assert e.value.reason == ErrorReason.INVALID_AFTER_SANITIZE
 
-    @pytest.mark.skipif(sys.version_info < (3, 6), reason="requires python3.6 or higher")
     @pytest.mark.parametrize(
         ["value", "expected"],
-        [[1, TypeError], [True, TypeError], [nan, TypeError], [inf, TypeError]],
+        [
+            [1, TypeError],
+            [True, TypeError],
+            [nan, TypeError],
+            [inf, TypeError],
+        ],
     )
     def test_exception_type(self, value, expected):
         with pytest.raises(expected):
